@@ -1,6 +1,6 @@
 module.exports = {
 	root: true,
-	plugins: ["prettier", "node", "jest"],
+	plugins: ["prettier", "node", "jest", "jsdoc"],
 	extends: [
 		"eslint:recommended",
 		"plugin:node/recommended",
@@ -33,31 +33,50 @@ module.exports = {
 		"no-loop-func": "warn",
 		indent: "off",
 		"no-console": "off",
-		"valid-jsdoc": [
-			"error",
-			{
-				prefer: {
-					return: "returns",
-					prop: "property",
-					memberof: "DONTUSE",
-					class: "DONTUSE",
-					inheritdoc: "DONTUSE",
-					description: "DONTUSE",
-					readonly: "DONTUSE"
-				},
-				preferType: {
-					"*": "any"
-				},
-				requireReturnType: true
-			}
-		],
 		"node/no-unsupported-features": "error",
 		"node/no-deprecated-api": "error",
 		"node/no-missing-import": "error",
 		"node/no-missing-require": ["error", { allowModules: ["webpack"] }],
 		"node/no-unpublished-bin": "error",
 		"node/no-unpublished-require": "error",
-		"node/process-exit-as-throw": "error"
+		"node/process-exit-as-throw": "error",
+		"jsdoc/require-hyphen-before-param-description": ["error", "never"],
+		"jsdoc/check-tag-names": "error",
+		"jsdoc/check-param-names": "error",
+		"jsdoc/require-param-description": "error",
+		"jsdoc/require-param-name": "error",
+		"jsdoc/require-param-type": "error",
+		"jsdoc/require-param": "error",
+		"jsdoc/require-returns-description": "error",
+		"jsdoc/require-returns-type": "error",
+		"jsdoc/require-returns": "error"
+	},
+	settings: {
+		jsdoc: {
+			// supported tags https://github.com/microsoft/TypeScript-wiki/blob/master/JSDoc-support-in-JavaScript.md
+			tagNamePreference: {
+				...["implements", "const", "memberof", "readonly", "yields"].reduce(
+					(acc, tag) => {
+						acc[tag] = {
+							message: `@${tag} currently not supported in Typescript`
+						};
+						return acc;
+					},
+					{}
+				),
+				extends: "extends",
+				return: "returns",
+				constructor: "constructor",
+				prop: "property",
+				arg: "param",
+				augments: "extends",
+				description: false,
+				desc: false,
+				inheritdoc: false,
+				class: false
+			},
+			overrideReplacesDocs: false
+		}
 	},
 	overrides: [
 		{
