@@ -14,13 +14,15 @@ const benchmarkOptions = {
 };
 
 function runTimes(compiler, times, deferred) {
-	fs.writeFileSync(path.join(fixtures, "0.js"), "module.exports = " + Math.random(), "utf-8");
+	fs.writeFileSync(
+		path.join(fixtures, "0.js"),
+		"module.exports = " + Math.random(),
+		"utf-8"
+	);
 	compiler.run(err => {
-		if(err) throw err;
-		if(times === 1)
-			deferred.resolve();
-		else
-			runTimes(compiler, times - 1, deferred);
+		if (err) throw err;
+		if (times === 1) deferred.resolve();
+		else runTimes(compiler, times - 1, deferred);
 	});
 }
 
@@ -28,103 +30,102 @@ const tests = {
 	"normal build": [
 		[0, 1, 5, 10, 50, 100, 200],
 		(size, deferred) => {
-			webpack({
-				context: fixtures,
-				entry: `./${size}.js`,
-				output: {
-					path: outputPath,
-					filename: "bundle.js"
+			webpack(
+				{
+					context: fixtures,
+					entry: `./${size}.js`,
+					output: {
+						path: outputPath,
+						filename: "bundle.js"
+					}
+				},
+				err => {
+					if (err) throw err;
+					deferred.resolve();
 				}
-			}, err => {
-				if(err) throw err;
-				deferred.resolve();
-			});
+			);
 		}
 	],
 	"eval dev build": [
 		[0, 1, 2, 5, 10, 15],
 		(size, deferred) => {
-			webpack({
-				context: fixtures,
-				entry: `./${size}.big.js`,
-				output: {
-					path: outputPath,
-					filename: "bundle.js"
+			webpack(
+				{
+					context: fixtures,
+					entry: `./${size}.big.js`,
+					output: {
+						path: outputPath,
+						filename: "bundle.js"
+					},
+					devtool: "eval"
 				},
-				devtool: "eval"
-			}, err => {
-				if(err) throw err;
-				deferred.resolve();
-			});
+				err => {
+					if (err) throw err;
+					deferred.resolve();
+				}
+			);
 		}
 	],
 	"sourcemap build": [
 		[0, 1, 2, 5, 10, 15],
 		(size, deferred) => {
-			webpack({
-				context: fixtures,
-				entry: `./${size}.big.js`,
-				output: {
-					path: outputPath,
-					filename: "bundle.js"
+			webpack(
+				{
+					context: fixtures,
+					entry: `./${size}.big.js`,
+					output: {
+						path: outputPath,
+						filename: "bundle.js"
+					},
+					devtool: "source-map"
 				},
-				devtool: "source-map"
-			}, err => {
-				if(err) throw err;
-				deferred.resolve();
-			});
+				err => {
+					if (err) throw err;
+					deferred.resolve();
+				}
+			);
 		}
 	],
 	"cheap sourcemap build": [
 		[0, 1, 2, 5, 10, 15],
 		(size, deferred) => {
-			webpack({
-				context: fixtures,
-				entry: `./${size}.big.js`,
-				output: {
-					path: outputPath,
-					filename: "bundle.js"
+			webpack(
+				{
+					context: fixtures,
+					entry: `./${size}.big.js`,
+					output: {
+						path: outputPath,
+						filename: "bundle.js"
+					},
+					devtool: "cheap-source-map"
 				},
-				devtool: "cheap-source-map"
-			}, err => {
-				if(err) throw err;
-				deferred.resolve();
-			});
+				err => {
+					if (err) throw err;
+					deferred.resolve();
+				}
+			);
 		}
 	],
 	"build w/ chunks": [
 		[0, 1, 5, 10, 50, 100, 200],
 		(size, deferred) => {
-			webpack({
-				context: fixtures,
-				entry: `./${size}.async.js`,
-				output: {
-					path: outputPath,
-					filename: "bundle.js"
+			webpack(
+				{
+					context: fixtures,
+					entry: `./${size}.async.js`,
+					output: {
+						path: outputPath,
+						filename: "bundle.js"
+					}
+				},
+				err => {
+					if (err) throw err;
+					deferred.resolve();
 				}
-			}, err => {
-				if(err) throw err;
-				deferred.resolve();
-			});
+			);
 		}
 	],
-	"build w/ chunks": [
-		[0, 1, 5, 10, 50, 100, 200],
-		(size, deferred) => {
-			webpack({
-				context: fixtures,
-				entry: "./" + size + ".async.js",
-				output: {
-					path: outputPath,
-					filename: "bundle.js"
-				}
-			}, err => {
-				if(err) throw err;
-				deferred.resolve();
-			});
-		}
-	],
-	"incremental": [
+	incremental: [
 		[0, 1, 5, 10, 50, 100, 200],
 		(size, deferred) => {
 			var compiler = webpack({
@@ -155,7 +156,7 @@ const tests = {
 			runTimes(compiler, size, deferred);
 		}
 	],
-	"incremental2": [
+	incremental2: [
 		[0, 1, 5, 10, 50, 100, 200],
 		(size, deferred) => {
 			var compiler = webpack({
@@ -170,7 +171,7 @@ const tests = {
 			runTimes(compiler, 3, deferred);
 		}
 	],
-	"incremental4": [
+	incremental4: [
 		[0, 1, 5, 10, 50, 100, 200],
 		(size, deferred) => {
 			var compiler = webpack({
@@ -185,7 +186,7 @@ const tests = {
 			runTimes(compiler, 5, deferred);
 		}
 	],
-	"incremental16": [
+	incremental16: [
 		[0, 1, 5, 10, 50, 100, 200],
 		(size, deferred) => {
 			var compiler = webpack({
@@ -199,25 +200,38 @@ const tests = {
 			});
 			runTimes(compiler, 17, deferred);
 		}
-	],
+	]
 };
 
-const suite = new Benchmark.Suite;
+const suite = new Benchmark.Suite();
 
-Object.keys(tests).filter(name => process.argv.length > 2 ? name.includes(process.argv[2]) : true)
+Object.keys(tests)
+	.filter(name =>
+		process.argv.length > 2 ? name.includes(process.argv[2]) : true
+	)
 	.forEach(name => {
 		const test = tests[name];
 		test[0].forEach(size => {
-			suite.add(`${name} ${size}`, deferred => {
-				test[1](size, deferred);
-			}, benchmarkOptions);
+			suite.add(
+				`${name} ${size}`,
+				deferred => {
+					test[1](size, deferred);
+				},
+				benchmarkOptions
+			);
 		});
 	});
 
 suite.on("cycle", event => {
 	process.stderr.write("\n");
 	const b = event.target;
-	console.log(b.name + "\t" + Math.floor(1000 * (b.stats.mean - b.stats.moe)) + "\t" + Math.floor(1000 * (b.stats.mean + b.stats.moe)));
+	console.log(
+		b.name +
+			"\t" +
+			Math.floor(1000 * (b.stats.mean - b.stats.moe)) +
+			"\t" +
+			Math.floor(1000 * (b.stats.mean + b.stats.moe))
+	);
 });
 
 suite.run({
