@@ -2,16 +2,17 @@ var path = require("path");
 var webpack = require("../../../");
 
 module.exports = {
+	// mode: "development" || "production",
 	context: __dirname,
 	entry: "./example-app",
 	output: {
 		filename: "app.js",
-		path: path.resolve(__dirname, "js"),
+		path: path.resolve(__dirname, "dist")
 	},
 	plugins: [
 		new webpack.DllReferencePlugin({
 			context: ".",
-			manifest: require("../0-vendor/js/vendor-manifest.json"), // eslint-disable-line
-		}),
-	],
+			manifest: require("../0-vendor/dist/vendor-manifest.json") // eslint-disable-line
+		})
+	]
 };
