@@ -3,21 +3,24 @@ var webpack = require("../../");
 module.exports = [
 	{
 		name: "vendor",
+		// mode: "development || "production",
 		entry: ["./vendor", "./vendor2"],
 		output: {
-			path: path.resolve(__dirname, "js"),
+			path: path.resolve(__dirname, "dist"),
 			filename: "vendor.js",
 			library: "vendor_[hash]"
 		},
 		plugins: [
 			new webpack.DllPlugin({
 				name: "vendor_[hash]",
-				path: path.resolve(__dirname, "js/manifest.json")
+				path: path.resolve(__dirname, "dist/manifest.json")
 			})
 		]
 	},
+
 	{
 		name: "app",
+		// mode: "development || "production",
 		dependencies: ["vendor"],
 		entry: {
 			pageA: "./pageA",
@@ -25,12 +28,12 @@ module.exports = [
 			pageC: "./pageC"
 		},
 		output: {
-			path: path.join(__dirname, "js"),
+			path: path.join(__dirname, "dist"),
 			filename: "[name].js"
 		},
 		plugins: [
 			new webpack.DllReferencePlugin({
-				manifest: path.resolve(__dirname, "js/manifest.json")
+				manifest: path.resolve(__dirname, "dist/manifest.json")
 			})
 		]
 	}
