@@ -1,9 +1,11 @@
 var path = require("path");
 var webpack = require("../../");
 module.exports = {
+	// mode: "development || "production",
+	cache: true, // better performance for the AggressiveSplittingPlugin
 	entry: "./example",
 	output: {
-		path: path.join(__dirname, "js"),
+		path: path.join(__dirname, "dist"),
 		filename: "[chunkhash].js",
 		chunkFilename: "[chunkhash].js"
 	},
@@ -16,5 +18,5 @@ module.exports = {
 			"process.env.NODE_ENV": JSON.stringify("production")
 		})
 	],
-	recordsOutputPath: path.join(__dirname, "js", "records.json")
+	recordsOutputPath: path.join(__dirname, "dist", "records.json")
 };
