@@ -3,9 +3,10 @@ var webpack = require("../../");
 module.exports = [
 	{
 		name: "mobile",
+		// mode: "development || "production",
 		entry: "./example",
 		output: {
-			path: path.join(__dirname, "js"),
+			path: path.join(__dirname, "dist"),
 			filename: "mobile.js"
 		},
 		plugins: [
@@ -14,11 +15,13 @@ module.exports = [
 			})
 		]
 	},
+
 	{
 		name: "desktop",
+		// mode: "development || "production",
 		entry: "./example",
 		output: {
-			path: path.join(__dirname, "js"),
+			path: path.join(__dirname, "dist"),
 			filename: "desktop.js"
 		},
 		plugins: [
