@@ -1,5 +1,4 @@
 var path = require("path");
-var webpack = require("../../");
 
 module.exports = [
 	"cheap-eval-source-map",
@@ -11,17 +10,18 @@ module.exports = [
 	"hidden-source-map",
 	"inline-source-map",
 	"nosources-source-map",
-	"source-map",
+	"source-map"
 ].map(devtool => ({
+	mode: "development",
 	entry: {
-		bundle: "coffee-loader!./example.coffee",
+		bundle: "coffee-loader!./example.coffee"
 	},
 	output: {
-		path: path.join(__dirname, "js"),
-		filename: `./[name]-${devtool}.js`,
+		path: path.join(__dirname, "dist"),
+		filename: `./[name]-${devtool}.js`
 	},
 	devtool,
-	plugins: [
-		new webpack.optimize.CommonsChunkPlugin(["manifest"]),
-	],
+	optimization: {
+		runtimeChunk: true
+	}
 }));
