@@ -8,19 +8,22 @@ module.exports = function(updatedModules, renewedModules) {
 	});
 	var log = require("./log");
 
-	if(unacceptedModules.length > 0) {
-		log("warning", "[HMR] The following modules couldn't be hot updated: (They would need a full reload!)");
+	if (unacceptedModules.length > 0) {
+		log(
+			"warning",
+			"[HMR] The following modules couldn't be hot updated: (They would need a full reload!)"
+		);
 		unacceptedModules.forEach(function(moduleId) {
 			log("warning", "[HMR]  - " + moduleId);
 		});
 	}
 
-	if(!renewedModules || renewedModules.length === 0) {
+	if (!renewedModules || renewedModules.length === 0) {
 		log("info", "[HMR] Nothing hot updated.");
 	} else {
 		log("info", "[HMR] Updated modules:");
 		renewedModules.forEach(function(moduleId) {
-			if(typeof moduleId === "string" && moduleId.indexOf("!") !== -1) {
+			if (typeof moduleId === "string" && moduleId.indexOf("!") !== -1) {
 				var parts = moduleId.split("!");
 				log.groupCollapsed("info", "[HMR]  - " + parts.pop());
 				log("info", "[HMR]  - " + moduleId);
@@ -32,7 +35,10 @@ module.exports = function(updatedModules, renewedModules) {
 		var numberIds = renewedModules.every(function(moduleId) {
 			return typeof moduleId === "number";
 		});
-		if(numberIds)
-			log("info", "[HMR] Consider using the NamedModulesPlugin for module names.");
+		if (numberIds)
+			log(
+				"info",
+				"[HMR] Consider using the NamedModulesPlugin for module names."
+			);
 	}
 };
