@@ -4,7 +4,7 @@
 */
 "use strict";
 
-var ExternalModuleFactoryPlugin = require("./ExternalModuleFactoryPlugin");
+const ExternalModuleFactoryPlugin = require("./ExternalModuleFactoryPlugin");
 
 class ExternalsPlugin {
 	constructor(type, externals) {
@@ -12,8 +12,10 @@ class ExternalsPlugin {
 		this.externals = externals;
 	}
 	apply(compiler) {
-		compiler.plugin("compile", (params) => {
-			params.normalModuleFactory.apply(new ExternalModuleFactoryPlugin(this.type, this.externals));
+		compiler.hooks.compile.tap("ExternalsPlugin", ({ normalModuleFactory }) => {
+			new ExternalModuleFactoryPlugin(this.type, this.externals).apply(
+				normalModuleFactory
+			);
 		});
 	}
 }
