@@ -10,8 +10,13 @@ class LoaderTargetPlugin {
 	}
 
 	apply(compiler) {
-		compiler.plugin("compilation", (compilation) => {
-			compilation.plugin("normal-module-loader", (loaderContext) => loaderContext.target = this.target);
+		compiler.hooks.compilation.tap("LoaderTargetPlugin", compilation => {
+			compilation.hooks.normalModuleLoader.tap(
+				"LoaderTargetPlugin",
+				loaderContext => {
+					loaderContext.target = this.target;
+				}
+			);
 		});
 	}
 }
