@@ -6,8 +6,9 @@
 const HarmonyImportDependency = require("./HarmonyImportDependency");
 
 class HarmonyAcceptImportDependency extends HarmonyImportDependency {
-	constructor(request, importedVar, range) {
-		super(request, importedVar, range);
+	constructor(request, originModule, parserScope) {
+		super(request, originModule, NaN, parserScope);
+		this.weak = true;
 	}
 
 	get type() {
@@ -15,8 +16,8 @@ class HarmonyAcceptImportDependency extends HarmonyImportDependency {
 	}
 }
 
-HarmonyAcceptImportDependency.Template = class HarmonyAcceptImportDependencyTemplate {
-	apply(dep, source, outputOptions, requestShortener) {}
+HarmonyAcceptImportDependency.Template = class HarmonyAcceptImportDependencyTemplate extends HarmonyImportDependency.Template {
+	apply(dep, source, runtime) {}
 };
 
 module.exports = HarmonyAcceptImportDependency;
