@@ -1,10 +1,11 @@
 "use strict";
 
-/* globals expect fit */
+/* globals expect */
 const path = require("path");
 const fs = require("fs");
 const vm = require("vm");
 const checkArrayExpectation = require("./checkArrayExpectation");
+const createLazyTestEnv = require("./helpers/createLazyTestEnv");
 
 const webpack = require("../lib/webpack");
 
@@ -24,11 +25,10 @@ describe("HotTestCases", () => {
 	categories.forEach(category => {
 		describe(category.name, () => {
 			category.tests.forEach(testName => {
-				describe(
-					testName,
-					() => {
-						let exportedTests = [];
-						it(testName + " should compile", done => {
+				describe(testName, () => {
+					it(
+						testName + " should compile",
+						done => {
 							const testDirectory = path.join(
 								casesPath,
 								category.name,
@@ -50,6 +50,7 @@ describe("HotTestCases", () => {
 							let options = {};
 							if (fs.existsSync(configPath)) options = require(configPath);
 							if (!options.mode) options.mode = "development";
+							if (!options.devtool) options.devtool = false;
 							if (!options.context) options.context = testDirectory;
 							if (!options.entry) options.entry = "./index.js";
 							if (!options.output) options.output = {};
@@ -61,7 +62,6 @@ describe("HotTestCases", () => {
 							if (!options.module) options.module = {};
 							if (!options.module.rules) options.module.rules = [];
 							options.module.rules.push({
-								test: /\.js$/,
 								loader: path.join(
 									__dirname,
 									"hotCases",
@@ -106,14 +106,10 @@ describe("HotTestCases", () => {
 									return;
 								}
 
-								function _it(title, fn) {
-									exportedTests.push({ title, fn, timeout: 10000 });
-								}
-
 								function _next(callback) {
 									fakeUpdateLoaderOptions.updateIndex++;
 									compiler.run((err, stats) => {
-										if (err) return done(err);
+										if (err) return callback(err);
 										const jsonStats = stats.toJson({
 											errorDetails: true
 										});
@@ -124,7 +120,7 @@ describe("HotTestCases", () => {
 												"error",
 												"errors" + fakeUpdateLoaderOptions.updateIndex,
 												"Error",
-												done
+												callback
 											)
 										) {
 											return;
@@ -136,12 +132,12 @@ describe("HotTestCases", () => {
 												"warning",
 												"warnings" + fakeUpdateLoaderOptions.updateIndex,
 												"Warning",
-												done
+												callback
 											)
 										) {
 											return;
 										}
-										if (callback) callback(jsonStats);
+										callback(null, jsonStats);
 									});
 								}
 
@@ -151,6 +147,7 @@ describe("HotTestCases", () => {
 										const fn = vm.runInThisContext(
 											"(function(require, module, exports, __dirname, __filename, it, expect, NEXT, STATS) {" +
 												"global.expect = expect;" +
+												'function nsObj(m) { Object.defineProperty(m, Symbol.toStringTag, { value: "Module" }); return m; }' +
 												fs.readFileSync(p, "utf-8") +
 												"\n})",
 											p
@@ -174,29 +171,20 @@ describe("HotTestCases", () => {
 									} else return require(module);
 								}
 								_require("./bundle.js");
-								if (exportedTests.length < 1)
+								if (getNumberOfTests() < 1)
 									return done(new Error("No tests exported by test case"));
 
-								const asyncSuite = describe("exported tests", () => {
-									exportedTests.forEach(
-										({ title, fn, timeout }) =>
-											fn
-												? fit(title, fn, timeout)
-												: fit(title, () => {}).pend("Skipped")
-									);
-								});
-								// workaround for jest running clearSpies on the wrong suite (invoked by clearResourcesForRunnable)
-								asyncSuite.disabled = true;
-
-								jasmine
-									.getEnv()
-									.execute([asyncSuite.id], asyncSuite)
-									.then(done, done);
+								done();
 							});
-						});
-					},
-					10000
-				);
+						},
+						10000
+					);
+
+					const { it: _it, getNumberOfTests } = createLazyTestEnv(
+						jasmine.getEnv(),
+						10000
+					);
+				});
 			});
 		});
 	});
