@@ -4,8 +4,19 @@
 const path = require("path");
 const fs = require("fs");
 
-const webpack = require("../lib/webpack");
 const Stats = require("../lib/Stats");
+const captureStdio = require("./helpers/captureStdio");
+
+let webpack;
+
+/**
+ * Escapes regular expression metacharacters
+ * @param {string} str String to quote
+ * @returns {string} Escaped string
+ */
+const quotemeta = str => {
+	return str.replace(/[-[\]\\/{}()*+?.^$|]/g, "\\$&");
+};
 
 const base = path.join(__dirname, "statsCases");
 const outputBase = path.join(__dirname, "js", "stats");
@@ -27,6 +38,14 @@ const tests = fs
 	});
 
 describe("StatsTestCases", () => {
+	let stderr;
+	beforeEach(() => {
+		stderr = captureStdio(process.stderr, true);
+		webpack = require("../lib/webpack");
+	});
+	afterEach(() => {
+		stderr.restore();
+	});
 	tests.forEach(testName => {
 		it("should print correct stats for " + testName, done => {
 			jest.setTimeout(10000);
@@ -40,6 +59,17 @@ describe("StatsTestCases", () => {
 			if (fs.existsSync(path.join(base, testName, "webpack.config.js"))) {
 				options = require(path.join(base, testName, "webpack.config.js"));
 			}
+			let testConfig = {};
+			try {
+				// try to load a test file
+				testConfig = Object.assign(
+					testConfig,
+					require(path.join(base, testName, "test.config.js"))
+				);
+			} catch (e) {
+				// ignored
+			}
+
 			(Array.isArray(options) ? options : [options]).forEach(options => {
 				if (!options.context) options.context = path.join(base, testName);
 				if (!options.output) options.output = options.output || {};
@@ -102,20 +132,22 @@ describe("StatsTestCases", () => {
 				let actual = stats.toString(toStringOptions);
 				expect(typeof actual).toBe("string");
 				if (!hasColorSetting) {
+					actual = stderr.toString() + actual;
 					actual = actual
 						.replace(/\u001b\[[0-9;]*m/g, "")
-						.replace(/[0-9]+(\s?ms)/g, "X$1")
+						.replace(/[.0-9]+(\s?ms)/g, "X$1")
 						.replace(
 							/^(\s*Built at:) (.*)$/gm,
 							"$1 Thu Jan 01 1970 00:00:00 GMT"
 						);
 				} else {
+					actual = stderr.toStringRaw() + actual;
 					actual = actual
 						.replace(/\u001b\[1m\u001b\[([0-9;]*)m/g, "<CLR=$1,BOLD>")
 						.replace(/\u001b\[1m/g, "<CLR=BOLD>")
 						.replace(/\u001b\[39m\u001b\[22m/g, "</CLR>")
 						.replace(/\u001b\[([0-9;]*)m/g, "<CLR=$1>")
-						.replace(/[0-9]+(<\/CLR>)?(\s?ms)/g, "X$1$2")
+						.replace(/[.0-9]+(<\/CLR>)?(\s?ms)/g, "X$1$2")
 						.replace(
 							/^(\s*Built at:) (.*)$/gm,
 							"$1 Thu Jan 01 1970 <CLR=BOLD>00:00:00</CLR> GMT"
@@ -124,9 +156,14 @@ describe("StatsTestCases", () => {
 				actual = actual
 					.replace(/\r\n?/g, "\n")
 					.replace(/[\t ]*Version:.+\n/g, "")
-					.replace(path.join(base, testName), "Xdir/" + testName)
+					.replace(
+						new RegExp(quotemeta(path.join(base, testName)), "g"),
+						"Xdir/" + testName
+					)
+					.replace(/(\w)\\(\w)/g, "$1/$2")
 					.replace(/ dependencies:Xms/g, "");
 				expect(actual).toMatchSnapshot();
+				if (testConfig.validate) testConfig.validate(stats, stderr.toString());
 				done();
 			});
 		});
