@@ -8,7 +8,7 @@ describe("WebpackMissingModule", () => {
 		it("returns an error message based on given error message", () => {
 			const errorMessage = WebpackMissingModule.moduleCode("mock message");
 			expect(errorMessage).toBe(
-				'var e = new Error("Cannot find module \\"mock message\\""); e.code = \'MODULE_NOT_FOUND\'; throw e;'
+				"var e = new Error(\"Cannot find module 'mock message'\"); e.code = 'MODULE_NOT_FOUND'; throw e;"
 			);
 		});
 	});
@@ -17,7 +17,7 @@ describe("WebpackMissingModule", () => {
 		it("returns an error message based on given error message", () => {
 			const errorMessage = WebpackMissingModule.promise("mock message");
 			expect(errorMessage).toBe(
-				'Promise.reject(function webpackMissingModule() { var e = new Error("Cannot find module \\"mock message\\""); e.code = \'MODULE_NOT_FOUND\'; return e; }())'
+				"Promise.reject(function webpackMissingModule() { var e = new Error(\"Cannot find module 'mock message'\"); e.code = 'MODULE_NOT_FOUND'; return e; }())"
 			);
 		});
 	});
@@ -26,7 +26,7 @@ describe("WebpackMissingModule", () => {
 		it("returns an error message based on given error message", () => {
 			const errorMessage = WebpackMissingModule.module("mock message");
 			expect(errorMessage).toBe(
-				'!(function webpackMissingModule() { var e = new Error("Cannot find module \\"mock message\\""); e.code = \'MODULE_NOT_FOUND\'; throw e; }())'
+				"!(function webpackMissingModule() { var e = new Error(\"Cannot find module 'mock message'\"); e.code = 'MODULE_NOT_FOUND'; throw e; }())"
 			);
 		});
 	});
