@@ -1,5 +1,5 @@
 it("should hide stack in details", function() {
-	(function f() {
+	expect(function f() {
 		require("./loader!");
-	}).should.throw();
+	}).toThrowError();
 });
