@@ -7,11 +7,11 @@ import * as abc from "./abc";
 function x() { throw new Error("should not be executed"); }
 it("should have this = undefined on imported non-strict functions", function() {
 	x
-	d().should.be.eql("undefined");
+	expect(d()).toBe("undefined");
 	x
-	a().should.be.eql("undefined");
+	expect(a()).toBe("undefined");
 	x
-	B().should.be.eql("undefined");
+	expect(B()).toBe("undefined");
 });
 
 import C2, { C } from "./new";
@@ -20,9 +20,9 @@ import * as New from "./new";
 
 it("should be possible to use new correctly", function() {
 	x
-	new C().should.match({ok: true});
+	expect(new C()).toEqual({ok: true});
 	x
-	new C2().should.match({ok: true});
+	expect(new C2()).toEqual({ok: true});
 	x
-	new New.C().should.match({ok: true});
+	expect(new New.C()).toEqual({ok: true});
 });
