@@ -1,7 +1,7 @@
 it("should parse multiple expressions in a require", function(done) {
 	var name = "abc";
 	require(["./" + name + "/" + name + "Test"], function(x) {
-		x.should.be.eql("ok");
+		expect(x).toBe("ok");
 		done();
 	});
-});
\ No newline at end of file
+});
