@@ -7,14 +7,14 @@ it("should ignore require.config", function() {
 	});
 });
 it("should have a require.version", function() {
-	require.version.should.be.type("string");
+	expect(require.version).toBeTypeOf("string");
 });
 it("should have a requirejs.onError function", function() {
 	function f(){}
-	requirejs.onError.should.be.type("function"); // has default handler
+	expect(requirejs.onError).toBeTypeOf("function"); // has default handler
 	var org = requirejs.onError;
 	requirejs.onError = f;
-	requirejs.onError.should.be.eql(f);
+	expect(requirejs.onError).toBe(f);
 	requirejs.onError = org;
 	require(["./file.js"], function() {});
 });
