@@ -2,5 +2,5 @@ import a from './a';
 export default 'b-default';
 
 export function btest() {
-	a.should.be.eql("a-default");
+	expect(a).toBe("a-default");
 }
