@@ -1,4 +1,4 @@
 it("should have a require.onError function by default", function() {
-	(typeof require.onError).should.be.eql("function");
+	expect((typeof require.onError)).toBe("function");
 	require(["./file"]);
-});
\ No newline at end of file
+});
