@@ -1,5 +1,5 @@
 import value from "./async";
 
 it("should have the correct values", function() {
-	value.should.be.eql("default");
+	expect(value).toBe("default");
 });
