@@ -3,5 +3,5 @@ import "./module";
 import { log } from "./tracker";
 
 it("should evaluate import in the correct order", function() {
-	log.should.be.eql(["commonjs", "module"]);
+	expect(log).toEqual(["commonjs", "module"]);
 });
