@@ -2,7 +2,7 @@ import value, { self as moduleSelf } from "./module";
 export var self = require("./");
 
 it("should have the correct values", function() {
-	value.should.be.eql("default");
-	moduleSelf.should.be.eql(self);
-	self.self.should.be.eql(self);
+	expect(value).toBe("default");
+	expect(moduleSelf).toBe(self);
+	expect(self.self).toBe(self);
 });
