@@ -1,8 +1,6 @@
-require("should");
-
 require("./common");
 
 it("should have the correct main flag for multi first module", function() {
 	var multiModule = __webpack_require__.c[module.parents[0]];
-	multiModule.hot._main.should.be.eql(true);
+	expect(multiModule.hot._main).toBe(true);
 });
