@@ -2,7 +2,7 @@ var path = require("path");
 var webpack = require("../../../../");
 
 module.exports = {
-	entry: ["./a", "./b", "./_d", "./_e", "./f", "./g.abc"],
+	entry: ["./a", "./b", "./_d", "./_e", "./f", "./g.abc", "./h"],
 	resolve: {
 		extensions: [".js", ".jsx"]
 	},
@@ -19,9 +19,17 @@ module.exports = {
 				options: {
 					test: 1
 				}
+			},
+			{
+				test: /0-create-dll.h/,
+				sideEffects: false
 			}
 		]
 	},
+	optimization: {
+		usedExports: true,
+		sideEffects: true
+	},
 	plugins: [
 		new webpack.DllPlugin({
 			path: path.resolve(
