@@ -4,15 +4,17 @@ var webpack = require("../../../../");
 module.exports = {
 	module: {
 		rules: [
-			{ oneOf: [
-				{
-					test: /\.abc\.js$/,
-					loader: "../0-create-dll/g-loader.js",
-					options: {
-						test: 1
+			{
+				oneOf: [
+					{
+						test: /\.abc\.js$/,
+						loader: "../0-create-dll/g-loader.js",
+						options: {
+							test: 1
+						}
 					}
-				}
-			] }
+				]
+			}
 		]
 	},
 	resolve: {
