@@ -4,15 +4,17 @@ var webpack = require("../../../../");
 module.exports = {
 	module: {
 		rules: [
-			{ oneOf: [
-				{
-					test: /\.abc\.js$/,
-					loader: "../0-create-dll/g-loader.js",
-					options: {
-						test: 1
+			{
+				oneOf: [
+					{
+						test: /\.abc\.js$/,
+						loader: "../0-create-dll/g-loader.js",
+						options: {
+							test: 1
+						}
 					}
-				}
-			] }
+				]
+			}
 		]
 	},
 	plugins: [
@@ -22,6 +24,6 @@ module.exports = {
 			context: path.resolve(__dirname, "../0-create-dll"),
 			sourceType: "commonjs2"
 		}),
-		new webpack.HashedModuleIdsPlugin(),
+		new webpack.HashedModuleIdsPlugin()
 	]
 };
