@@ -1,16 +1,16 @@
 it("should move externals in chunks into entry chunk", function(done) {
 	var fs = require("fs");
 	var source = fs.readFileSync(__filename, "utf-8");
-	source.should.containEql("1+" + (1+1));
-	source.should.containEql("3+" + (2+2));
-	source.should.containEql("5+" + (3+3));
+	expect(source).toMatch("1+" + (1+1));
+	expect(source).toMatch("3+" + (2+2));
+	expect(source).toMatch("5+" + (3+3));
 
 	import("./chunk").then(function(chunk) {
-		chunk.a.should.be.eql(3);
-		chunk.b.then(function(chunk2) {
-			chunk2.should.be.eql(7);
+		expect(chunk.default.a).toBe(3);
+		chunk.default.b.then(function(chunk2) {
+			expect(chunk2.default).toBe(7);
 			import("external3").then(function(ex) {
-				ex.should.be.eql(11);
+				expect(ex.default).toBe(11);
 				done();
 			});
 		});
