@@ -1,5 +1,5 @@
 import external from "external";
 
 it("should harmony import a dependency", function() {
-	external.should.be.eql("abc");
+	expect(external).toBe("abc");
 });
