@@ -4,5 +4,9 @@ const IgnorePlugin = require("../../../../lib/IgnorePlugin");
 
 module.exports = {
 	entry: "./test.js",
-	plugins: [new IgnorePlugin(/ignored-module/)]
+	plugins: [
+		new IgnorePlugin({
+			resourceRegExp: /ignored-module/
+		})
+	]
 };
