@@ -5,6 +5,9 @@ const IgnorePlugin = require("../../../../lib/IgnorePlugin");
 module.exports = {
 	entry: "./test.js",
 	plugins: [
-		new IgnorePlugin(/ignored-module/, /folder-b/)
-	],
+		new IgnorePlugin({
+			resourceRegExp: /ignored-module/,
+			contextRegExp: /folder-b/
+		})
+	]
 };
