@@ -2,10 +2,10 @@ import * as M from "./module";
 
 it("should allow conditionals as callee", function() {
 	var x = (true ? M.fn : M.fn)();
-	x.should.be.eql("ok");
+	expect(x).toBe("ok");
 });
 
 it("should allow conditionals as object", function() {
 	var x = (true ? M : M).fn();
-	x.should.be.eql("ok");
+	expect(x).toBe("ok");
 });
