@@ -1,5 +1,3 @@
-require("should");
-
 it("should not load node-libs-browser when node option is false", function() {
-	(typeof process).should.be.eql("undefined");
+	expect((typeof process)).toBe("undefined");
 });
