@@ -1,5 +1,3 @@
-require("should");
-
 it("should add node-libs-browser to target web by default", function() {
-	process.browser.should.be.eql(true);
+	expect(process.browser).toBe(true);
 });
