@@ -7,7 +7,10 @@ module.exports = {
 	},
 	plugins: [
 		new LibManifestPlugin({
-			path: path.resolve(__dirname, "../../../js/config/plugins/lib-manifest-plugin/[name]-manifest.json"),
+			path: path.resolve(
+				__dirname,
+				"../../../js/config/plugins/lib-manifest-plugin/[name]-manifest.json"
+			),
 			name: "[name]_[hash]"
 		})
 	],
