@@ -1,18 +1,18 @@
 it("should combine two chunk if too small", done => {
 	// b should not yet available
 	var bf = __webpack_modules__[require.resolveWeak("./b")];
-	(typeof bf).should.be.eql("undefined");
+	expect((typeof bf)).toBe("undefined");
 
 	// load a
 	import("./a").then(a => {
-		a.default.should.be.eql("a");
+		expect(a.default).toBe("a");
 		// check if b is available too
 		var bf = __webpack_modules__[require.resolveWeak("./b")];
-		(typeof bf).should.be.eql("function");
+		expect((typeof bf)).toBe("function");
 
 		// load b (just to check if it's ok)
 		import("./b").then(b => {
-			b.default.should.be.eql("b");
+			expect(b.default).toBe("b");
 			done();
 		}).catch(done);
 	}).catch(done);
