@@ -1,4 +1,3 @@
-
 function createFunctionArrayFromUseArray(useArray) {
 	return useArray.map(function(useItem) {
 		return function(data) {
@@ -26,36 +25,28 @@ var useArray = createFunctionArrayFromUseArray([
 module.exports = {
 	module: {
 		rules: [
-			{ oneOf: [
-				{
-					test: {
-						and: [
-							/a.\.js$/,
-							/b\.js$/
-						]
+			{
+				oneOf: [
+					{
+						test: {
+							and: [/a.\.js$/, /b\.js$/]
+						},
+						loader: "./loader?first"
 					},
-					loader: "./loader?first"
-				},
-				{
-					test: [
-						require.resolve("./a"),
-						require.resolve("./c"),
-					],
-					issuer: require.resolve("./b"),
-					use: useArray
-				},
-				{
-					test: {
-						or: [
-							require.resolve("./a"),
-							require.resolve("./c"),
-						]
+					{
+						test: [require.resolve("./a"), require.resolve("./c")],
+						issuer: require.resolve("./b"),
+						use: useArray
 					},
-					loader: "./loader",
-					options: "third"
-				}
-			] }
+					{
+						test: {
+							or: [require.resolve("./a"), require.resolve("./c")]
+						},
+						loader: "./loader",
+						options: "third"
+					}
+				]
+			}
 		]
 	}
 };
-
