@@ -1,7 +1,8 @@
 module.exports = {
+	mode: "development",
 	node: {
 		__dirname: false,
 		__filename: false
 	},
-	devtool: "nosources-source-map",
+	devtool: "nosources-source-map"
 };
