@@ -1,10 +1,8 @@
-require("should");
-
 it("should provide a global Buffer shim", function () {
-	Buffer.should.be.a.Function();
+	expect(Buffer).toBeInstanceOf(Function);
 });
 
 it("should provide the buffer module", function () {
 	var buffer = require("buffer");
-	(typeof buffer).should.be.eql("object");
+	expect((typeof buffer)).toBe("object");
 });
