@@ -1,8 +1,10 @@
 module.exports = function supportArrowFunctionExpression() {
 	try {
-		eval("var foo = function(fn) {return fn.toString()}; foo(() => {return 'a'})");
+		eval(
+			"var foo = function(fn) {return fn.toString()}; foo(() => {return 'a'})"
+		);
 		return true;
-	} catch(e) {
+	} catch (e) {
 		return false;
 	}
 };
