@@ -1,15 +1,15 @@
 import a from "./loader!./a";
 
-it("should abort when module is not accepted", function(done) {
-	a.should.be.eql(1);
+it("should abort when module is not accepted", (done) => {
+	expect(a).toBe(1);
 	NEXT(require("../../update")(done, {
 		ignoreErrored: true
-	}, function() {
-		a.should.be.eql(1);
+	}, () => {
+		expect(a).toBe(1);
 		NEXT(require("../../update")(done, {
 			ignoreErrored: true
 		}, function() {
-			a.should.be.eql(3);
+			expect(a).toBe(3);
 			done();
 		}));
 	}));
