@@ -6,8 +6,6 @@ module.exports = {
 		hotUpdateChunkFilename: "[id].[hash].bundle-update.js",
 		hashDigestLength: 4
 	},
-	plugins: [
-		new webpack.HotModuleReplacementPlugin()
-	],
+	plugins: [new webpack.HotModuleReplacementPlugin()],
 	recordsPath: __dirname + "/records.json" // this is not required for the webpack-dev-server, but when compiled.
 };
