@@ -1,5 +1,8 @@
 var webpack = require("../../../");
-module.exports = {
+module.exports = ["fitting", "content-change"].map(type => ({
+	name: type,
+	mode: "production",
+	cache: true, // AggressiveSplittingPlugin rebuilds multiple times, we need to cache the assets
 	entry: "./index",
 	output: {
 		filename: "[chunkhash].js",
@@ -13,8 +16,8 @@ module.exports = {
 			maxSize: 2500
 		})
 	],
-	recordsInputPath: __dirname + "/input-records.json",
-	//recordsOutputPath: __dirname + "/records.json",
+	recordsInputPath: __dirname + `/input-records-${type}.json`,
+	//recordsOutputPath: __dirname + `/records-${type}.json`,
 	stats: {
 		chunks: true,
 		chunkModules: true,
@@ -23,4 +26,4 @@ module.exports = {
 		modules: false,
 		publicPath: true
 	}
-};
+}));
