@@ -1,17 +1,16 @@
 var ResolvePackageFromRootPlugin = require("./ResolvePackageFromRootPlugin");
 
 module.exports = {
+	mode: "production",
 	entry: "./index",
 	output: {
 		filename: "bundle.js"
 	},
 	resolve: {
-		plugins: [
-			new ResolvePackageFromRootPlugin(__dirname)
-		]
+		plugins: [new ResolvePackageFromRootPlugin(__dirname)]
 	},
 	stats: {
 		chunkModules: false,
-		modules: true,
+		modules: true
 	}
 };
