@@ -1,8 +1,9 @@
 module.exports = {
+	mode: "production",
 	entry: "./index",
 	performance: false,
 	stats: {
 		maxModules: 20,
-		modulesSort: "!id",
+		modulesSort: "!id"
 	}
 };
