@@ -1,4 +1,5 @@
 module.exports = {
+	mode: "production",
 	entry: "./index",
 	output: {
 		filename: "bundle.js"
@@ -13,6 +14,7 @@ module.exports = {
 		cachedAssets: true,
 		source: true,
 		errorDetails: true,
-		publicPath: true
+		publicPath: true,
+		outputPath: true
 	}
 };
